# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from apps.role.core.serializers import ThuxRoleSerializerMixin
from thx.api.serializers import ThuxCreateSerializerMixin, ThuxUpdateSerializerMixin


# CURRENCY
class CurrencySerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency'
        model = models.Currency
        fields = '__all__'


class CurrencyCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return CurrencySerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_currency_currency_create'
        model = models.Currency
        fields = '__all__'


class CurrencyUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return CurrencySerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_currency_currency_update'
        model = models.Currency
        fields = '__all__'


class CurrencyEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_currency_currency_enable'
        model = models.Currency
        fields = '__all__'

    def to_representation(self, instance):
        return CurrencySerializer(instance, context=self.context).data


class CurrencyDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_currency_currency_disable'
        model = models.Currency
        fields = '__all__'

    def to_representation(self, instance):
        return CurrencySerializer(instance, context=self.context).data
